You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by si...@apache.org on 2013/05/27 09:38:39 UTC

svn commit: r1486528 - /commons/proper/chain/trunk/core/src/main/java/org/apache/commons/chain2/CatalogFactory.java

Author: simonetripodi
Date: Mon May 27 07:38:38 2013
New Revision: 1486528

URL: http://svn.apache.org/r1486528
Log:
if the ConfigParser is not available in the classpath, then the application is in an illegal status

Modified:
    commons/proper/chain/trunk/core/src/main/java/org/apache/commons/chain2/CatalogFactory.java

Modified: commons/proper/chain/trunk/core/src/main/java/org/apache/commons/chain2/CatalogFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/chain/trunk/core/src/main/java/org/apache/commons/chain2/CatalogFactory.java?rev=1486528&r1=1486527&r2=1486528&view=diff
==============================================================================
--- commons/proper/chain/trunk/core/src/main/java/org/apache/commons/chain2/CatalogFactory.java (original)
+++ commons/proper/chain/trunk/core/src/main/java/org/apache/commons/chain2/CatalogFactory.java Mon May 27 07:38:38 2013
@@ -226,8 +226,8 @@ public abstract class CatalogFactory<K, 
 
     /**
      * Check to see if we have an implementation of a valid configuration
      * parsing class loaded at runtime. If not, we throw a
      * ChainConfigurationException.
      */
     public static void checkForValidConfigurationModule() {
         try {
@@ -237,7 +237,7 @@ public abstract class CatalogFactory<K, 
             String msg = "Couldn't not find a configuration implementation. " +
                     "Load a chain configuration module such as xml-configuration " +
                     "into the classpath and try again.";
-            throw new RuntimeException(msg, e);
+            throw new IllegalStateException(msg, e);
         }
     }
 }
@@ -226,8 +226,8 @@ public abstract class CatalogFactory<K, 
     /**
      * Check to see if we have an implementation of a valid configuration
-     * parsing class loaded at runtime. If not, we throw a
-     * ChainConfigurationException.
+     * parsing class loaded at runtime. If not, we throw an
+     * IllegalStateException.
      */
     public static void checkForValidConfigurationModule() {